<?php
include_once('aside.php');
if ($_SESSION['type'] == "staff") {
    header("Location: 404.php");
    exit();
}
// Enable error reporting for debugging
error_reporting(E_ALL);
ini_set('display_errors', 1);

$msg="";

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $name = $_POST['sname'];
    $dob = $_POST['sdob'];
    $email = $_POST['smail'];
    $phone = $_POST['sphone'];
    $salary = $_POST['ssalary'];
    $type = $_POST['stype'];
    $address = $_POST['saddress'];
    $pass = $_POST['spass'];

    // Check if email already exists in the staff table
    $checkEmailSql = "SELECT stuf_email FROM staff WHERE stuf_email = ?";
    $stmt = $conn->prepare($checkEmailSql);
    $stmt->bind_param("s", $email);
    $stmt->execute();
    $stmt->store_result();

    if ($stmt->num_rows > 0) {
        $msg = "Error: This email is already registered.";
    } else {
        $stmt->close();

        // Insert into 'staff' table
        $sql = "INSERT INTO staff (stuf_name, stuf_dob, stuf_email, stuf_phone, stuf_salary, stuf_type, stuf_address) VALUES (?, ?, ?, ?, ?, ?, ?)";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("sssssss", $name, $dob, $email, $phone, $salary, $type, $address);

        if ($stmt->execute()) {
            // Close the statement after staff insertion
            $stmt->close();

            // Only insert into 'users' table if password is provided
            if (!empty($pass)) {
                // Check if the phone is unique in the 'users' table
                $checkPhoneSql = "SELECT user_unique FROM users WHERE user_unique = ?";
                $stmt = $conn->prepare($checkPhoneSql);
                $stmt->bind_param("s", $phone);
                $stmt->execute();
                $stmt->store_result();

                if ($stmt->num_rows > 0) {
                    $msg = "Error: This phone number is already registered for a password.";
                } else {
                    $stmt->close();

                    // Insert into 'users' table
                    $newPASS = password_hash($pass, PASSWORD_BCRYPT);
                    $sql = "INSERT INTO users (user_name, user_unique, user_pass) VALUES (?, ?, ?)";
                    $stmt = $conn->prepare($sql);
                    $stmt->bind_param("sss", $name, $phone, $newPASS);

                    if ($stmt->execute()) {
                        // Redirect only after both inserts are successful
                        header('Location: list_of_staff.php');
                        exit();
                    } else {
                        echo "Error inserting into 'users' table: " . $conn->error;
                    }
                }
            } else {
                // Redirect if no password is provided after inserting into 'staff' table
                header('Location: list_of_staff.php');
                exit();
            }
        } else {
            echo "Error inserting into 'staff' table: " . $conn->error;
        }
    }

    $stmt->close();
}

$conn->close();
?>
<div class="main p-lg-3">
    <div class="container">
        <h2>Add a new staff</h2>
        <p><?php echo $msg; ?></p>
        <form action="<?php echo htmlspecialchars($_SERVER['PHP_SELF']); ?>" method="post">
            <div class="row">
                <div class="col-md-6">
                    <label for="sname">Name</label>
                    <input type="text" id="sname" name="sname" class="form-control" required>
                </div>
                <div class="col-md-6">
                    <label for="sdob">Date of birth</label>
                    <input type="date" id="sdob" name="sdob" class="form-control" required>
                </div>
                <div class="col-md-6">
                    <label for="smail">Email</label>
                    <input type="email" id="smail" name="smail" class="form-control" required>
                </div>
                <div class="col-md-6">
                    <label for="sphone">Phone</label>
                    <input type="text" id="sphone" name="sphone" class="form-control" required>
                </div>
                <div class="col-md-6">
                    <label for="ssalary">Salary</label>
                    <input type="text" id="ssalary" name="ssalary" class="form-control" required>
                </div>
                <div class="col-md-6">
                    <label for="stype">Type</label>
                    <input type="text" id="stype" name="stype" class="form-control" required>
                </div>
                <div class="col-md-12">
                    <label for="saddress">Address</label>
                    <input type="text" id="saddress" name="saddress" class="form-control" required>
                </div>
                <div class="col-md-12">
                    <label for="spass">Password (optional)</label>
                    <input type="password" id="spass" name="spass" class="form-control">
                </div>
            </div>
            <button type="submit" class="btn btn-main mt-2">Add staff</button>
        </form>
    </div>
</div>
<?php
include_once('footer.php');
?>
