<?php
include_once('aside.php');

$name = $dob = $email = $phone = $salary = $type = $address = '';
$staffid = 0;

if (isset($_GET['id'])) {
    $staffid = intval($_GET['id']);
    $sql = "SELECT * FROM staff WHERE stuf_id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("i", $staffid);
    $stmt->execute();
    $result = $stmt->get_result();
    $data = $result->fetch_assoc();
    $name = $data['stuf_name'];
    $dob = $data['stuf_dob'];
    $email = $data['stuf_email'];
    $phone = $data['stuf_phone'];
    $salary = $data['stuf_salary'];
    $type = $data['stuf_type'];
    $address = $data['stuf_address'];
} else {
    $name = '';
}

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $name = htmlspecialchars($_POST['sname']);
    $dob = htmlspecialchars($_POST['sdob']);
    $email = filter_var($_POST['smail'], FILTER_SANITIZE_EMAIL);
    $phone = htmlspecialchars($_POST['sphone']);
    $salary = htmlspecialchars($_POST['ssalary']);
    $type = htmlspecialchars($_POST['stype']);
    $address = htmlspecialchars($_POST['saddress']);
    
    // Validate input fields
    if (empty($name) || empty($dob) || !filter_var($email, FILTER_VALIDATE_EMAIL) || empty($phone) || empty($salary) || empty($type) || empty($address)) {
        echo "Please fill in all fields correctly.";
    } else {
        if (isset($_GET['id'])) {
            $sql = "UPDATE staff SET stuf_name=?, stuf_dob=?, stuf_email=?, stuf_phone=?, stuf_salary=?, stuf_type=?, stuf_address=? WHERE stuf_id=?";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param("sssssssi", $name, $dob, $email, $phone, $salary, $type, $address, $staffid);
        } else {
            $sql = "INSERT INTO staff (stuf_name, stuf_dob, stuf_email, stuf_phone, stuf_salary, stuf_type, stuf_address) VALUES (?, ?, ?, ?, ?, ?, ?)";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param("sssssss", $name, $dob, $email, $phone, $salary, $type, $address);
        }

        if ($stmt->execute()) {
            header('Location: list_of_staff.php');
            exit();
        } else {
            echo "Error: " . $stmt->error;
        }

        $stmt->close();
        $conn->close();
    }
}
?>

<div class="main p-lg-3">
    <div class="container">
        <form action="<?php echo htmlspecialchars($_SERVER['PHP_SELF']) . (isset($staffid) ? '?id=' . $staffid : ''); ?>" method="post">
            <div class="row">
                <div class="col-md-6">
                    <label for="sname">Name</label>
                    <input type="text" id="sname" name="sname" class="form-control" value="<?php echo htmlspecialchars($name); ?>" required>
                </div>
                <div class="col-md-6">
                    <label for="sdob">Date of Birth</label>
                    <input type="date" id="sdob" name="sdob" class="form-control" value="<?php echo htmlspecialchars($dob); ?>" required>
                </div>
                <div class="col-md-6">
                    <label for="smail">Email</label>
                    <input type="email" id="smail" name="smail" class="form-control" value="<?php echo htmlspecialchars($email); ?>" required>
                </div>
                <div class="col-md-6">
                    <label for="sphone">Phone</label>
                    <input type="text" id="sphone" name="sphone" class="form-control" value="<?php echo htmlspecialchars($phone); ?>" required>
                </div>
                <div class="col-md-6">
                    <label for="ssalary">Salary</label>
                    <input type="text" id="ssalary" name="ssalary" class="form-control" value="<?php echo htmlspecialchars($salary); ?>" required>
                </div>
                <div class="col-md-6">
                    <label for="stype">Type</label>
                    <input type="text" id="stype" name="stype" class="form-control" value="<?php echo htmlspecialchars($type); ?>" required>
                </div>
                <div class="col-md-12">
                    <label for="saddress">Address</label>
                    <input type="text" id="saddress" name="saddress" class="form-control" value="<?php echo htmlspecialchars($address); ?>" required>
                </div>
            </div>
            <button type="submit" class="btn btn-main mt-2">Update Staff</button>
        </form>
    </div>
</div>

<?php
include_once('footer.php');
?>
