<?php
include_once('aside.php');

// Database connection (Assuming $conn is already defined somewhere)
$currentDate = date("Y-m-d H:i:s"); // Current timestamp
$firstDateOfYear = date("Y-01-01 00:00:00"); // Start of the year
$firstDateOfMonth = date("Y-m-01 00:00:00"); // Start of the month
$endOfMonth = date("Y-m-t 23:59:59"); // End of the month

// Prepared Statements for Security
$queries = [
    'month' => "SELECT SUM(transaction_amount) AS total_amount FROM transaction WHERE created_at BETWEEN ? AND ?",
    'year' => "SELECT SUM(transaction_amount) AS total_amount FROM transaction WHERE created_at BETWEEN ? AND ?",
    'patients' => "SELECT COUNT(id) AS total FROM patients",
    'prescriptions' => "SELECT COUNT(id) AS total FROM prescription_new",
    'transactions' => "SELECT * FROM transaction ORDER BY id DESC LIMIT 10",
    'patientsList' => "SELECT * FROM patients ORDER BY id DESC LIMIT 10"
];

function executeQuery($conn, $query, $params = [], $fetchAll = false) {
    $stmt = mysqli_prepare($conn, $query);
    if ($stmt) {
        if ($params) {
            // Assuming all params are strings
            $types = str_repeat('s', count($params));
            mysqli_stmt_bind_param($stmt, $types, ...$params);
        }
        // Execute without passing arguments to execute()
        mysqli_stmt_execute($stmt);
        $result = mysqli_stmt_get_result($stmt);
        if ($fetchAll) {
            return mysqli_fetch_all($result, MYSQLI_ASSOC);
        } else {
            return mysqli_fetch_assoc($result);
        }
    }
    return null;
}

// Fetch data
$profitThisMonthData = executeQuery($conn, $queries['month'], [$firstDateOfMonth, $endOfMonth]);
$profitThisYearData = executeQuery($conn, $queries['year'], [$firstDateOfYear, $currentDate]);
$totalPatients = executeQuery($conn, $queries['patients']);
$totalPrescriptions = executeQuery($conn, $queries['prescriptions']);
$recentTransactions = executeQuery($conn, $queries['transactions'], [], true);
$recentPatients = executeQuery($conn, $queries['patientsList'], [], true);

$ProfitInThisMonth = $profitThisMonthData['total_amount'] ?? '0';
$ProfitInThisYear = $profitThisYearData['total_amount'] ?? '0';
$PatientCount = $totalPatients['total'] ?? '0';
$PrescriptionCount = $totalPrescriptions['total'] ?? '0';
?>
<div class="main p-lg-3">
    <div class="container">
        <h3>DashBoard</h3>
        <?php
        if (isset($_SESSION['type']) && $_SESSION['type'] == "staff") {
            
        } else {        
        ?>
        <div class="row justify-content-around">
            <div class="col-lg-3 text-center Fist-box-db py-5">
                <h4 class="text-danger">Profit In this Month</h4>
                <b><?php echo htmlspecialchars($ProfitInThisMonth); ?> &#2547;</b>
            </div>
            <div class="col-lg-3 text-center Fist-box-db py-5">
                <h4 class="text-primary">Profit In this Year</h4>
                <b><?php echo htmlspecialchars($ProfitInThisYear); ?> &#2547;</b>
            </div>
            <div class="col-lg-2 text-center Fist-box-db py-5">
                <h4 class="text-success">Total Patients</h4>
                <b><?php echo htmlspecialchars($PatientCount); ?>+</b>
            </div>
            <div class="col-lg-3 text-center Fist-box-db py-5">
                <h4 class="text-warning">Prescription Written</h4>
                <b><?php echo htmlspecialchars($PrescriptionCount); ?>+</b>
            </div>
        </div>
        <div class="row justify-content-between">
            <div class="col-lg-6 col-12">
                <div class="bg-body rounded my-5 p-2">
                    <h3 class="my-2"><a href="all_transaction.php" target='_blank' style="text-decoration:underline;">Last 10 Transactions</a></h3>
                    <table class="table">
                        <?php if ($recentTransactions): ?>
                            <?php foreach ($recentTransactions as $index => $transaction): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($index + 1); ?></td>
                                    <td><?php echo htmlspecialchars($transaction["transaction_title"]); ?></td>
                                    <td><?php echo htmlspecialchars($transaction["transaction_payment_method"]); ?></td>
                                    <td><?php echo htmlspecialchars($transaction["transaction_amount"]); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php else: ?>
                            <tr><td colspan='4'>No transactions found.</td></tr>
                        <?php endif; ?>
                    </table>
                </div>
            </div>
            <div class="col-lg-6">
                <div class="bg-body rounded my-5 p-2">
                    <h3 class="my-2"><a href="list_of_patients.php" target='_blank' style="text-decoration:underline;">Last 10 Patients</a></h3>
                    <table class="table">
                        <?php if ($recentPatients): ?>
                            <?php foreach ($recentPatients as $index => $patient): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($index + 1); ?></td>
                                    <td><?php echo htmlspecialchars($patient["P_Name"]); ?></td>
                                    <td><?php echo htmlspecialchars($patient["P_Phone"]); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php else: ?>
                            <tr><td colspan='3'>No patients found.</td></tr>
                        <?php endif; ?>
                    </table>
                </div>
            </div>
        </div>
    </div>
</div>

<?php
}
include_once('footer.php');
?>
