<?php
include_once('aside.php');

// Check if P_Unique is provided in the query string
if (isset($_GET['punique'])) {
    $getid = $_GET['punique'];

    // Use prepared statements to prevent SQL injection
    $stmt = $conn->prepare("SELECT P_Name, P_Unique FROM patients WHERE P_Unique = ?");
    $stmt->bind_param("s", $getid);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $data = $result->fetch_assoc();
        $name = htmlspecialchars($data['P_Name']);
        $P_Unique = $getid; // Use the original $getid to avoid XSS
    } else {
        echo "No patient found with the provided ID.";
        exit; // Exit if no patient found
    }

    $stmt->close();
} else {
    echo "No P_Unique provided.";
    exit; // Exit if no P_Unique provided
}

// Process form submission
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Validate form data
    $title = htmlspecialchars($_POST['title']);
    $ammount = floatval($_POST['ammount']);
    $todaypaid = floatval($_POST['todaypaid']);
    $date = $_POST['date']; // Ensure date is validated/formatted as needed
    $punique=$_POST['punique'];

    // Get current timestamp with milliseconds
    $timestamp = microtime(true); // Get current Unix timestamp with microseconds

    // Convert timestamp to formatted date string with milliseconds
    $final_timestamp = date("Y-m-d-H-i-s", $timestamp) . '-' . sprintf('%03d', ($timestamp - floor($timestamp)) * 1000);

    // Use prepared statement for INSERT to prevent SQL injection
    $insert_query = "INSERT INTO deal (title, ammount, todaypaid, timestamp, name, punique, date) VALUES (?, ?, ?, ?, ?, ?, ?)";
    $stmt = $conn->prepare($insert_query);
    $stmt->bind_param("sssssss", $title, $ammount, $todaypaid, $final_timestamp, $name, $punique, $date);
    
    if ($stmt->execute()) {
        $stmt->close();

        // Insert into transaction table
        $sql = "INSERT INTO transaction (transaction_title, transaction_payment_method, transaction_payer, transaction_amount) VALUES (?, 'cash', ?, ?)";
        $stmt2 = $conn->prepare($sql);
        $stmt2->bind_param("sss", $title, $name, $todaypaid);

        if ($stmt2->execute()) {
            $stmt2->close();

            // Redirect to print_deal.php if successful
            header("Location: print_deal.php?timestamp=$final_timestamp");
            exit;
        } else {
            echo "Error: " . $sql . "<br>" . $conn->error;
        }
    } else {
        echo "Error: " . $insert_query . "<br>" . $conn->error;
    }

    echo $P_Unique;
}
?>
<div class="main">
    <form action="<?php echo htmlspecialchars($_SERVER['PHP_SELF'])."?punique=".$P_Unique; ?>" method="post" class="p-1">
        <h3>Create New Deal</h3>
        <input type="text" name="punique" hidden value=<?php echo $P_Unique?>>
        <div class="row">
            <div class="col-lg-6"><input type="text" name="title" placeholder="Deal Title" class="form-control my-3" required></div>
            <div class="col-lg-6"><input type="text" name="ammount" placeholder="Deal Amount" class="form-control my-3" required></div>
            <div class="col-lg-6"><input type="text" name="todaypaid" placeholder="Today Paid" class="form-control my-3" required></div>
            <div class="col-lg-6"><input type="text" name="name" placeholder="Payer" class="form-control my-3" value="<?php echo htmlspecialchars($name); ?>" disabled></div>
            <div class="col-12"><input type="date" name="date" placeholder="Date" class="form-control my-3" required></div>
        </div>
       <button type="submit" class="btn btn-primary">Submit</button>
    </form>
</div>
<?php
include_once('footer.php');
?>
